@@ -44,7 +44,9 @@ class KilosortSorter(BaseSorter):
         'freq_max': 6000,
         'ntbuff': 64,
         'Nfilt': None,
-        'NT': None
+        'NT': None,
+        'chunk_mb': 500,
+        'n_jobs_bin': 1
     }
 
     _params_description = {
@@ -55,7 +57,9 @@ class KilosortSorter(BaseSorter):
         'freq_max': "Low-pass filter cutoff frequency",
         'ntbuff': "Samples of symmetrical buffer for whitening and spike detection",
         'Nfilt': "Number of clusters to use (if None it is automatically computed)",
-        'NT': "Batch size (if None it is automatically computed)"
+        'NT': "Batch size (if None it is automatically computed)",
+        'chunk_mb': "Chunk size in Mb for saving to binary format (default 500Mb)",
+        'n_jobs_bin': "Number of jobs for saving to binary format (Default 1)"
     }
 
     sorter_description = """Kilosort is a GPU-accelerated and efficient template-matching spike sorter. 
@@ -110,7 +114,8 @@ class KilosortSorter(BaseSorter):
 
         # save binary file
         input_file_path = output_folder / 'recording'
-        recording.write_to_binary_dat_format(input_file_path, dtype='int16', chunk_mb=500)
+        recording.write_to_binary_dat_format(input_file_path, dtype='int16', chunk_mb=p["chunk_mb"],
+                                             n_jobs=p["n_jobs_bin"], verbose=self.verbose)
 
         # set up kilosort config files and run kilosort on data
         with (source_dir / 'kilosort_master.m').open('r') as f:
@@ -160,7 +165,7 @@ class KilosortSorter(BaseSorter):
             dat_file=str((output_folder / 'recording.dat').absolute()),
             Nfilt=int(p['Nfilt']),
             ntbuff=int(p['ntbuff']),
-            NT=int(p['Nt']),
+            NT=int(p['NT']),
             kilo_thresh=p['detect_threshold'],
             use_car=use_car,
             freq_min=p['freq_min'],
@@ -189,9 +194,10 @@ class KilosortSorter(BaseSorter):
         recording = recover_recording(recording)
         if 'win' in sys.platform and sys.platform != 'darwin':
             shell_cmd = '''
+                        {disk_move}
                         cd {tmpdir}
                         matlab -nosplash -wait -log -r kilosort_master
-                    '''.format(tmpdir=output_folder)
+                    '''.format(disk_move=str(output_folder)[:2], tmpdir=output_folder)
         else:
             shell_cmd = '''
                         #!/bin/bash
