@@ -36,7 +36,7 @@ class Kilosort2Sorter(BaseSorter):
     requires_locations = False
 
     _default_params = {
-        'detect_threshold': 5,
+        'detect_threshold': 6,
         'projection_threshold': [10, 4],
         'preclust_threshold': 8,
         'car': True,
@@ -48,7 +48,9 @@ class Kilosort2Sorter(BaseSorter):
         'ntbuff': 64,
         'nfilt_factor': 4,
         'NT': None,
-        'keep_good_only': False
+        'keep_good_only': False,
+        'chunk_mb': 500,
+        'n_jobs_bin': 1
     }
 
     _params_description = {
@@ -67,7 +69,9 @@ class Kilosort2Sorter(BaseSorter):
         'sigmaMask': "Spatial constant in um for computing residual variance of spike",
         'nPCs': "Number of PCA dimensions",
         'nfilt_factor': "Max number of clusters per good channel (even temporary ones) 4",
-        'keep_good_only': "If True only 'good' units are returned"
+        'keep_good_only': "If True only 'good' units are returned",
+        'chunk_mb': "Chunk size in Mb for saving to binary format (default 500Mb)",
+        'n_jobs_bin': "Number of jobs for saving to binary format (Default 1)"
     }
 
     sorter_description = """Kilosort2 is a GPU-accelerated and efficient template-matching spike sorter. On top of its 
@@ -123,7 +127,8 @@ class Kilosort2Sorter(BaseSorter):
 
         # save binary file
         input_file_path = output_folder / 'recording.dat'
-        recording.write_to_binary_dat_format(input_file_path, dtype='int16', chunk_mb=500)
+        recording.write_to_binary_dat_format(input_file_path, dtype='int16', chunk_mb=p["chunk_mb"],
+                                             n_jobs=p["n_jobs_bin"], verbose=self.verbose)
 
         if p['car']:
             use_car = 1
@@ -193,9 +198,10 @@ class Kilosort2Sorter(BaseSorter):
         recording = recover_recording(recording)
         if 'win' in sys.platform and sys.platform != 'darwin':
             shell_cmd = '''
+                        {disk_move}
                         cd {tmpdir}
                         matlab -nosplash -wait -log -r kilosort2_master
-                    '''.format(tmpdir=output_folder)
+                    '''.format(disk_move=str(output_folder)[:2], tmpdir=output_folder)
         else:
             shell_cmd = '''
                         #!/bin/bash
