@@ -5,9 +5,11 @@ from .mountainsort4 import Mountainsort4Sorter
 from .ironclust import IronClustSorter
 from .kilosort import KilosortSorter
 from .kilosort2 import Kilosort2Sorter
+from .kilosort2_5 import Kilosort2_5Sorter
 from .spyking_circus import SpykingcircusSorter
 from .herdingspikes import HerdingspikesSorter
 from .waveclus import WaveClusSorter
+from .combinato import CombinatoSorter
 
 sorter_full_list = [
     HDSortSorter,
@@ -17,9 +19,11 @@ sorter_full_list = [
     IronClustSorter,
     KilosortSorter,
     Kilosort2Sorter,
+    Kilosort2_5Sorter,
     SpykingcircusSorter,
     HerdingspikesSorter,
-    WaveClusSorter
+    WaveClusSorter,
+    CombinatoSorter
 ]
 
 sorter_dict = {s.sorter_name: s for s in sorter_full_list}
@@ -445,6 +449,42 @@ def run_kilosort2(*args, **kwargs):
     """
     return run_sorter('kilosort2', *args, **kwargs)
 
+def run_kilosort2_5(*args, **kwargs):
+    """
+    Runs kilosort2_5 sorter
+
+    Parameters
+    ----------
+    *args: arguments of 'run_sorter'
+        recording: RecordingExtractor
+            The recording extractor to be spike sorted
+        output_folder: str or Path
+            Path to output folder
+        delete_output_folder: bool
+            If True, output folder is deleted (default False)
+        grouping_property: str
+            Splits spike sorting by 'grouping_property' (e.g. 'groups')
+        parallel: bool
+            If True and spike sorting is by 'grouping_property', spike sorting jobs are launched in parallel
+        verbose: bool
+            If True, output is verbose
+        raise_error: bool
+            If True, an error is raised if spike sorting fails (default). If False, the process continues and the error
+            is logged in the log file
+        n_jobs: int
+            Number of jobs when parallel=True (default=-1)
+        joblib_backend: str
+            joblib backend when parallel=True (default='loky')
+    **kwargs: keyword args
+        Spike sorter specific arguments (they can be retrieved with 'get_default_params('kilosort2')
+
+    Returns
+    -------
+    sortingextractor: SortingExtractor
+        The spike sorted data
+    """
+    return run_sorter('kilosort2_5', *args, **kwargs)
+
 
 def run_spykingcircus(*args, **kwargs):
     """
@@ -555,3 +595,40 @@ def run_waveclus(*args, **kwargs):
         The spike sorted data
     """
     return run_sorter('waveclus', *args, **kwargs)
+
+
+def run_combinato(*args, **kwargs):
+    """
+    Runs combinato sorter
+
+    Parameters
+    ----------
+    *args: arguments of 'run_sorter'
+        recording: RecordingExtractor
+            The recording extractor to be spike sorted
+        output_folder: str or Path
+            Path to output folder
+        delete_output_folder: bool
+            If True, output folder is deleted (default False)
+        grouping_property: str
+            Splits spike sorting by 'grouping_property' (e.g. 'groups')
+        parallel: bool
+            If True and spike sorting is by 'grouping_property', spike sorting jobs are launched in parallel
+        verbose: bool
+            If True, output is verbose
+        raise_error: bool
+            If True, an error is raised if spike sorting fails (default). If False, the process continues and the error
+            is logged in the log file
+        n_jobs: int
+            Number of jobs when parallel=True (default=-1)
+        joblib_backend: str
+            joblib backend when parallel=True (default='loky')
+    **kwargs: keyword args
+        Spike sorter specific arguments (they can be retrieved with 'get_default_params('waveclus')
+
+    Returns
+    -------
+    sortingextractor: SortingExtractor
+        The spike sorted data
+    """
+    return run_sorter('combinato', *args, **kwargs)
